@@ -22,7 +22,7 @@ int main( int argc, char* argv[] )
     QApplication app( argc, argv );
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral( "klickety" )));
 
-    KLocalizedString::setApplicationDomain("klickety");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("klickety"));
 
     KAboutData aboutData( QStringLiteral( "klickety" ), i18n( "Klickety" ), QStringLiteral( KLICKETY_VERSION_STRING ),
                           i18n( "Klickety is an adaptation of the \"clickomania\" game" ),
@@ -31,10 +31,12 @@ int main( int argc, char* argv[] )
                           QString(),
                           QStringLiteral("https://apps.kde.org/klickety"));
 
-    QCommandLineParser parser;
     KAboutData::setApplicationData( aboutData );
+
     KCrash::initialize();
-    parser.addOption( QCommandLineOption( QStringList() <<  QStringLiteral( "KSameMode" ), i18n( "Start with KSame compatibility mode" ) ) );
+
+    QCommandLineParser parser;
+    parser.addOption( QCommandLineOption({QStringLiteral("KSameMode")}, i18n("Start with KSame compatibility mode")));
 
     aboutData.setupCommandLine( &parser );
     parser.process( app );
